﻿/*
This file is under Microsoft Public License (MS-PL)
Copyright Yohann MARTEL.  All rights reserved.
Codeplex: http://amf.codeplex.com
AMF Website: http://www.ymartel.com/aspnet-mobile-framework/
*/

using System;
using System.ComponentModel;
using System.Web.UI;

namespace Mobile.WebControls
{
    [ToolboxData("<{0}:AccordionItem runat=server></{0}:AccordionItem>")]
    public class AccordionItem : Div
    {
        #region Properties
        [Browsable(false), DefaultValue(null), PersistenceMode(PersistenceMode.InnerProperty),
         TemplateContainer(typeof(SimpleTemplate))]
        public ITemplate Content { get; set; }

        [Bindable(true)]
        public object DataItem { get; set; }

        [Category("Appearance")]
        public bool DataCollapsed { get; set; }

        [Category("Appearance")]
        public DataTheme ContentTheme { get; set; }

        public override ControlCollection Controls
        {
            get
            {
                EnsureChildControls();
                return base.Controls;
            }
        }
        #endregion

        #region Methods
        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            if (Content != null)
            {
                SimpleTemplate contentContainer = new SimpleTemplate();
                Content.InstantiateIn(contentContainer);
                Controls.Add(contentContainer);
                contentContainer.DataBind();
            }

        }
        #endregion

        #region Constructor
        public AccordionItem()
        {
            //default value: Collapsed 
            DataCollapsed = true;
        }
        #endregion

        #region Render Methods
        protected override void AddAttributesToRender(HtmlTextWriter writer)
        {
            base.AddAttributesToRender(writer);
            writer.AddAttribute(MetadataAttribute.DataRole, DataRole.Collapsible);
            if (!DataCollapsed)
            {
                writer.AddAttribute(MetadataAttribute.DataCollapsed, Boolean.FalseString.ToLower());
            }

            if (ContentTheme != DataTheme.None)
            {
                writer.AddAttribute(MetadataAttribute.DataContentTheme, Enum.GetName(typeof(DataTheme), ContentTheme).ToLower());
            }
        }
        #endregion
    }
}
