﻿/*
This file is under Microsoft Public License (MS-PL)
Copyright Yohann MARTEL.  All rights reserved.
Codeplex: http://amf.codeplex.com
AMF Website: http://www.ymartel.com/aspnet-mobile-framework/
*/
using System;
using System.ComponentModel;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace Mobile.WebControls.Field
{
    public class RadioButtonList : DataBoundControl
    {
        #region Properties
        [Category("Functionality")]
        public string Text { get; set; }

        [Category("Data")]
        public string DataTextField { get; set; }

        [Category("Data")]
        public string DataValueField { get; set; }

        [Category("Client")]
        public string FieldName { get; set; }

        [Category("Appearance")]
        public DataTheme Theme { get; set; }

        [Category("Appearance")]
        public DataType DataType { get; set; }
        #endregion

        #region Methods
        private void AddLegendControl()
        {
            Legend legend = new Legend { Text = Text };
            Controls.Add(legend);
        }

        protected override void PerformDataBinding(System.Collections.IEnumerable datas)
        {
            AddLegendControl();
            if (datas != null)
            {
                foreach (object dataItem in datas)
                {
                    object propTextField = DataBinder.GetPropertyValue(dataItem, DataTextField);
                    object propValueField = DataBinder.GetPropertyValue(dataItem, DataValueField);
                    InputItem inputItem = new InputItem();
                    inputItem.InputType = InputType.Radio;
                    inputItem.Theme = Theme;
                    if (propTextField != null)
                    {
                        inputItem.LabelText = propTextField.ToString();
                    }
                    if (propValueField != null)
                    {
                        inputItem.FieldValue = propValueField.ToString();
                    }
                    if (!String.IsNullOrEmpty(FieldName))
                    {
                        inputItem.FieldName = FieldName;
                    }
                    Controls.Add(inputItem);
                }
            }
        }
        #endregion

        #region Render Methods
        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            AddAttributesToRender(writer);
            writer.RenderBeginTag(HtmlTextWriterTag.Fieldset);
        }

        public override void RenderEndTag(HtmlTextWriter writer)
        {
            writer.RenderEndTag();
        }

        protected override void AddAttributesToRender(HtmlTextWriter writer)
        {
            base.AddAttributesToRender(writer);
            writer.AddAttribute(MetadataAttribute.DataRole, DataRole.ControlGroup);
            if (DataType != DataType.Default)
            {
                writer.AddAttribute(MetadataAttribute.DataType, Enum.GetName(typeof(DataType), DataType).ToLower());
            }
            if (Theme != DataTheme.None)
            {
                writer.AddAttribute(MetadataAttribute.DataTheme, Enum.GetName(typeof(DataTheme), Theme).ToLower());
            }
        }
        #endregion
    }
}
