﻿/*
This file is under Microsoft Public License (MS-PL)
Copyright Yohann MARTEL.  All rights reserved.
Codeplex: http://amf.codeplex.com
AMF Website: http://www.ymartel.com/aspnet-mobile-framework/
*/

using System;
using System.ComponentModel;
using System.Web.UI;

namespace Mobile.WebControls
{
    public class Form: BaseControl
    {
        #region Properties
        [Browsable(false), DefaultValue(null), PersistenceMode(PersistenceMode.InnerProperty),
         TemplateContainer(typeof(SimpleTemplate))]
        public ITemplate Content { get; set; }

        [Category("HTML")]
        public string Action { get; set; }

        [Category("HTML")]
        public FormMethod Method { get; set; }

        public override ControlCollection Controls
        {
            get
            {
                EnsureChildControls();
                return base.Controls;
            }
        }
        #endregion

        #region Methods
        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            if (Content != null)
            {
                SimpleTemplate contentContainer = new SimpleTemplate();
                Content.InstantiateIn(contentContainer);
                Controls.Add(contentContainer);
            }

        }
        #endregion

        #region Render Methods
        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            AddAttributesToRender(writer);
            writer.RenderBeginTag(HtmlTextWriterTag.Form);
        }

        public override void RenderEndTag(HtmlTextWriter writer)
        {
            writer.RenderEndTag(); // </form>
        }

        protected override void AddAttributesToRender(HtmlTextWriter writer)
        {
            base.AddAttributesToRender(writer);
            writer.AddAttribute(MobileHtmlTextWriterAttribute.Method, Enum.GetName(typeof(FormMethod), Method).ToLower());
            if(!String.IsNullOrEmpty(Action))
            {
                writer.AddAttribute(MobileHtmlTextWriterAttribute.Action, Action);
            }
        }
        #endregion
    }
}
